<?php
namespace PrestaShop\Module\LCVPrestaConnector\Models;

/**
 * Objet d'interface contenant la définition du stock d'un produit
 */
class Stock extends SanitizedObject
{
    /**
     * Identifiants du produit sous le backoffice
     * 
     * @param array<string> Références
     */    
    public array $refs;

    /**
     * EAN fournisseurs
     * 
     * @param array<string> Références
     */    
    public ?array $eans;

    /**
     * Quantité en stock, par code magasin
     * 
     * @var array<string, int>
     */
    public array $qties = [];

    /**
     * Prix de vente
     */
    public ?float $prixTTC = null;
    
    /**
     * Nouveau stock
     * 
     * @param array<string> $refs code barres de la référence
     * @param array<string, int> $qties Quantité
     */
    public function __construct(
        array $refs,
        array $qties
        )
    {
        // Sanitize
        $this->refs = $refs;
        $this->qties = $qties;
    }

    /**
     * Nettoyage de la donnée sur les standards Prestashop
     */
    public function sanitize()
    {
        for ($i = 0; $i < count($this->eans); $i++)
            $this->eans[$i] = $this->sanitizeStr($this->eans[$i], 32);
    }
}